#[non_exhaustive]pub enum Error {
Decode(Error),
InvalidSession(String),
Io(Error),
Other(String),
}Expand description
An error at a native session-format boundary.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Decode(Error)
A serialized value could not be decoded or encoded.
InvalidSession(String)
A persisted session artifact violated its framing or schema contract.
Io(Error)
A filesystem operation failed.
Other(String)
A format-specific operation failed without a narrower stable category.