NodeId

Type Alias NodeId 

pub type NodeId = String;
A tree-node id. Assigned by SessionTree’s monotonic allocator — a counter ("n0", "n1", …), not content-derived or random, so ids are deterministic and trivially testable, and so two nodes can never collide.

Aliased Type

pub struct NodeId { /* private fields */ }